@@ -1,6 +1,13 @@
-/* demo/rakuraku/kihon/kihon5.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -16,7 +23,7 @@ static integer c__601 = 601;
 static integer c__41 = 41;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -67,14 +74,14 @@ static integer c__41 = 41;
     sgopn_(&iws);
     sglset_("LSOFTF", &c_true, (ftnlen)6);
     sgfrm_();
-/* -- ǥե ---- */
+/* -- デフォルト ---- */
     sgtnv_(&c__6, x, y);
-/* -- ȡѥ ---- */
+/* -- トーンパターン ---- */
     sgstnp_(&c__3);
     sgtnv_(&c__6, &x[41], &y[41]);
     sgstnp_(&c__601);
     sgtnv_(&c__6, &x[82], &y[82]);
-/* -- ͤ줿¿ѷ ---- */
+/* -- ねじれた多角形 ---- */
     sgtnv_(&c__41, &x[123], &y[123]);
     sgcls_();
     return 0;
