@@ -1,6 +1,13 @@
-/* demo/rakuraku/quick/quick3.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -19,7 +26,7 @@ static real c_b13 = .8f;
 static integer c__37 = 37;
 
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Main program */ int MAIN__(void)
 {
@@ -47,7 +54,7 @@ static integer c__37 = 37;
     static cilist io___8 = { 0, 5, 0, 0, 0 };
 
 
-/* -- Ĵ´ؿ ---- */
+/* -- 球面調和関数 ---- */
     for (j = 1; j <= 37; ++j) {
 	for (i__ = 1; i__ <= 37; ++i__) {
 	    alon = ((i__ - 1) * 360.f / 36 + 0.f) * .017453277777777776f;
@@ -63,7 +70,7 @@ static integer c__37 = 37;
 	}
 /* L20: */
     }
-/* --  ---- */
+/* -- グラフ ---- */
     s_wsle(&io___7);
     do_lio(&c__9, &c__1, " WORKSTATION ID (I)  ? ;", (ftnlen)24);
     e_wsle();
