@@ -23,7 +23,7 @@ extern void f_exit(void);
 extern int atexit(void (*)(void));
 
 extern void f_init(void), sig_die(char*, int);
-extern int MAIN__(void);
+//extern int MAIN__(void);
 #define Int int
 
 static VOID sigfdie(Sigarg)
@@ -119,7 +119,7 @@ main(int argc, char **argv)
 
 	f_init();
 	atexit(f_exit);
-	MAIN__();
+//	MAIN__();
 	exit(0);	/* exit(0) rather than return(0) to bypass Cray bug */
 	return 0;	/* For compilers that complain of missing return values; */
 			/* others will complain that this is unreachable code. */
