@@ -30,7 +30,7 @@ static integer c__2 = 2;
     /* Subroutine */ int s_cat(char *, char **, integer *, integer *, ftnlen);
 
 /* Writing concatenation */
-    i__1[0] = 1, a__1[0] = "x";
+    i__1[0] = 2, a__1[0] = "\\x";
     *(unsigned char *)&ch__2[0] = *ic;
     i__1[1] = 1, a__1[1] = ch__2;
     s_cat(ret_val, a__1, i__1, &c__2, (ftnlen)3);
