@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -20,7 +20,7 @@ static doublereal c_b19 = 10.;
 /* ----------------------------------------------------------------------- */
 /*     NORMALIZATION TRANSFORMATION (INCLUDING MAP PROJECTION) */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int stftrn_0_(int n__, real *ux, real *uy, real *vx, real *
 	vy, integer *itr, real *cxa, real *cya, real *vxoff, real *vyoff)
@@ -46,22 +46,29 @@ static doublereal c_b19 = 10.;
 	    real *), mpicoa_(real *, real *, real *, real *), mpicoc_(real *, 
 	    real *, real *, real *), mpfaza_(real *, real *, real *, real *), 
 	    mpfbon_(real *, real *, real *, real *), mpfcon_(real *, real *, 
-	    real *, real *), mpiaza_(real *, real *, real *, real *), mpibon_(
+	    real *, real *), mpfvdg_(real *, real *, real *, real *), mpfmil_(
 	    real *, real *, real *, real *), mpfktd_(real *, real *, real *, 
 	    real *), mpfmer_(real *, real *, real *, real *), msgdmp_(char *, 
-	    char *, char *, ftnlen, ftnlen, ftnlen), mpiktd_(real *, real *, 
+	    char *, char *, ftnlen, ftnlen, ftnlen), mpfplc_(real *, real *, 
 	    real *, real *), mpfhmr_(real *, real *, real *, real *), mpfcyl_(
 	    real *, real *, real *, real *), mpfmwd_(real *, real *, real *, 
-	    real *), mpfotg_(real *, real *, real *, real *), mpfazm_(real *, 
-	    real *, real *, real *), mpicyl_(real *, real *, real *, real *), 
-	    mpimer_(real *, real *, real *, real *), mpimwd_(real *, real *, 
-	    real *, real *), mpihmr_(real *, real *, real *, real *), mpicon_(
+	    real *), mpfrbs_(real *, real *, real *, real *), mpfsin_(real *, 
+	    real *, real *, real *), mpfotg_(real *, real *, real *, real *), 
+	    mpfazm_(real *, real *, real *, real *), mpfgno_(real *, real *, 
+	    real *, real *), mpicyl_(real *, real *, real *, real *), mpimer_(
 	    real *, real *, real *, real *), sgqwnd_(real *, real *, real *, 
-	    real *), mpiotg_(real *, real *, real *, real *), mpiazm_(real *, 
-	    real *, real *, real *), glrget_(char *, real *, ftnlen), mpfpst_(
-	    real *, real *, real *, real *), mpipst_(real *, real *, real *, 
-	    real *), stfusr_(real *, real *, real *, real *), stiusr_(real *, 
-	    real *, real *, real *);
+	    real *), mpimwd_(real *, real *, real *, real *), mpihmr_(real *, 
+	    real *, real *, real *), mpiktd_(real *, real *, real *, real *), 
+	    mpimil_(real *, real *, real *, real *), mpirbs_(real *, real *, 
+	    real *, real *), mpfpst_(real *, real *, real *, real *), mpisin_(
+	    real *, real *, real *, real *), mpivdg_(real *, real *, real *, 
+	    real *), mpicon_(real *, real *, real *, real *), mpibon_(real *, 
+	    real *, real *, real *), mpiplc_(real *, real *, real *, real *), 
+	    mpiotg_(real *, real *, real *, real *), mpipst_(real *, real *, 
+	    real *, real *), mpiazm_(real *, real *, real *, real *), mpiaza_(
+	    real *, real *, real *, real *), mpigno_(real *, real *, real *, 
+	    real *), stfusr_(real *, real *, real *, real *), glrget_(char *, 
+	    real *, ftnlen), stiusr_(real *, real *, real *, real *);
 
     switch(n__) {
 	case 1: goto L_stitrn;
@@ -120,6 +127,14 @@ static doublereal c_b19 = 10.;
 	mpfek6_(ux, uy, &xx, &yy);
     } else if (itrz == 15) {
 	mpfktd_(ux, uy, &xx, &yy);
+    } else if (itrz == 16) {
+	mpfmil_(ux, uy, &xx, &yy);
+    } else if (itrz == 17) {
+	mpfrbs_(ux, uy, &xx, &yy);
+    } else if (itrz == 18) {
+	mpfsin_(ux, uy, &xx, &yy);
+    } else if (itrz == 19) {
+	mpfvdg_(ux, uy, &xx, &yy);
     } else if (itrz == 20) {
 	mpfcon_(ux, uy, &xx, &yy);
     } else if (itrz == 21) {
@@ -128,6 +143,8 @@ static doublereal c_b19 = 10.;
 	mpfcoc_(ux, uy, &xx, &yy);
     } else if (itrz == 23) {
 	mpfbon_(ux, uy, &xx, &yy);
+    } else if (itrz == 24) {
+	mpfplc_(ux, uy, &xx, &yy);
     } else if (itrz == 30) {
 	mpfotg_(ux, uy, &xx, &yy);
     } else if (itrz == 31) {
@@ -136,6 +153,10 @@ static doublereal c_b19 = 10.;
 	mpfazm_(ux, uy, &xx, &yy);
     } else if (itrz == 33) {
 	mpfaza_(ux, uy, &xx, &yy);
+    } else if (itrz == 34) {
+	mpfgno_(ux, uy, &xx, &yy);
+    } else if (itrz == 40) {
+	mpfvdg_(ux, uy, &xx, &yy);
     } else if (itrz == 51) {
 	g2fctr_(ux, uy, &xx, &yy);
     } else if (itrz == 99) {
@@ -190,6 +211,14 @@ L_stitrn:
 	mpiek6_(&xx, &yy, ux, uy);
     } else if (itrz == 15) {
 	mpiktd_(&xx, &yy, ux, uy);
+    } else if (itrz == 16) {
+	mpimil_(&xx, &yy, ux, uy);
+    } else if (itrz == 17) {
+	mpirbs_(&xx, &yy, ux, uy);
+    } else if (itrz == 18) {
+	mpisin_(&xx, &yy, ux, uy);
+    } else if (itrz == 19) {
+	mpivdg_(&xx, &yy, ux, uy);
     } else if (itrz == 20) {
 	mpicon_(&xx, &yy, ux, uy);
     } else if (itrz == 21) {
@@ -198,6 +227,8 @@ L_stitrn:
 	mpicoc_(&xx, &yy, ux, uy);
     } else if (itrz == 23) {
 	mpibon_(&xx, &yy, ux, uy);
+    } else if (itrz == 24) {
+	mpiplc_(&xx, &yy, ux, uy);
     } else if (itrz == 30) {
 	mpiotg_(&xx, &yy, ux, uy);
     } else if (itrz == 31) {
@@ -206,6 +237,8 @@ L_stitrn:
 	mpiazm_(&xx, &yy, ux, uy);
     } else if (itrz == 33) {
 	mpiaza_(&xx, &yy, ux, uy);
+    } else if (itrz == 34) {
+	mpigno_(&xx, &yy, ux, uy);
     } else if (itrz == 51) {
 	g2ictr_(&xx, &yy, ux, uy);
     } else if (itrz == 99) {
