@@ -1,6 +1,13 @@
-/* src/grph1/swpack/swcmll.f -- translated by f2c (version 20020621).
-   You must link the resulting object file with the libraries:
-	-lf2c -lm   (in that order)
+/*  -- translated by f2c (version 20100827).
+   You must link the resulting object file with libf2c:
+	on Microsoft Windows system, link with libf2c.lib;
+	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
+	or, if you install libf2c.a in a standard place, with -lf2c -lm
+	-- in that order, at the end of the command line, as in
+		cc *.o -lf2c -lm
+	Source for libf2c is in /netlib/f2c/libf2c.zip, e.g.,
+
+		http://www.netlib.org/f2c/libf2c.zip
 */
 
 #include "libtinyf2c.h"
@@ -14,7 +21,7 @@ static integer c__9 = 9;
 /* ----------------------------------------------------------------------- */
 /*     COLORMAP LIST LOADING */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int swcmll_0_(int n__, integer *nn, integer *ntx, char *ctf, 
 	char *ctd, ftnlen ctf_len, ftnlen ctd_len)
@@ -37,7 +44,7 @@ static integer c__9 = 9;
 
     /* Local variables */
     static integer n, nc, iu, ios;
-    static char ctr1[80*20], ctr2[80*20], cmsg[80], cfile[80];
+    static char ctr1[80*99], ctr2[80*99], cmsg[80], cfile[1024];
     extern /* Subroutine */ int chngi_(char *, char *, integer *, char *, 
 	    ftnlen, ftnlen, ftnlen);
     static integer nnmax;
@@ -61,15 +68,15 @@ static integer c__9 = 9;
 	return 0;
     }
 /*     / OPEN LIST FILE : MAYBE SYSTEM DEPENDENT / */
-    swqfnm_("CMAPLIST", cfile, (ftnlen)8, (ftnlen)80);
-    if (s_cmp(cfile, " ", (ftnlen)80, (ftnlen)1) == 0) {
+    swqfnm_("CMAPLIST", cfile, (ftnlen)8, (ftnlen)1024);
+    if (s_cmp(cfile, " ", (ftnlen)1024, (ftnlen)1) == 0) {
 	msgdmp_("E", "SWCMLL", "COLORMAP LIST DOES NOT EXIST.", (ftnlen)1, (
 		ftnlen)6, (ftnlen)29);
     }
     iu = iufopn_();
     o__1.oerr = 0;
     o__1.ounit = iu;
-    o__1.ofnmlen = 80;
+    o__1.ofnmlen = 1024;
     o__1.ofnm = cfile;
     o__1.orl = 0;
     o__1.osta = 0;
@@ -96,7 +103,7 @@ L100001:
 	msgdmp_("E", "SWCMLL", "COLORMAP LIST IS INVALID", (ftnlen)1, (ftnlen)
 		6, (ftnlen)24);
     }
-    if (nc > 20) {
+    if (nc > 99) {
 	msgdmp_("E", "SWCMLL", "COLORMAP LIST OVERFLOWS", (ftnlen)1, (ftnlen)
 		6, (ftnlen)23);
     }
