@@ -1,4 +1,4 @@
-﻿#ifdef WINDOWS
+#ifdef WINDOWS
 #include <io.h>
 #include <fcntl.h>
 #endif
@@ -1198,9 +1198,12 @@ void dcltext2pangomarkup(char* text, int textlength, char* string, double fontsi
 
   sg_small = getrparm("small");
   sg_shift = getrparm("shift");
-  sg_isup = getiparm("isup");
+/*  sg_isup = getiparm("isup");
   sg_isub = getiparm("isub");
-  sg_irst = getiparm("irst");
+  sg_irst = getiparm("irst");*/
+  sg_isup = 29;
+  sg_isub = 30;
+  sg_irst = 31;
   sg_lcntl = getlparm("lcntl");
 
 /* calculate rise amount for super-/sub-script from fontsize that in PangoUnits
@@ -1562,13 +1565,7 @@ void dcltext2pangomarkup(char* text, int textlength, char* string, double fontsi
 
     if (0){ /* 従来のDCL書式 */
       /* 制御文字をmarkup tagに。 */
-      if (dclextchar[i] == sg_isup && sg_lcntl){ /* 上付き開始 */
-        strcpy(&string[length], sup_span); length += strlen(sup_span); continue;
-      }else if(dclextchar[i] == sg_isub && sg_lcntl){ /* 下付き開始 */
-        strcpy(&string[length], sub_span); length += strlen(sub_span); continue;
-      }else if(dclextchar[i] == sg_irst && sg_lcntl){ /* span終了 */
-        strcpy(&string[length], "</span>"); length += strlen("</span>"); continue;
-      }else if(dclextchar[i] == 36 && sg_lcntl){ /* 暫定 $ で over を表現 */
+/*      else if(dclextchar[i] == 36){ // 暫定 $ で over を表現
         sw = char_width(" ", -1);
         cw0 = char_width(&dclextchar[prev_pos], prev_byte);
         cw1 = char_width(&dclextchar[i+1], utf8_char_byte(&dclextchar[i+1]));
@@ -1577,11 +1574,18 @@ void dcltext2pangomarkup(char* text, int textlength, char* string, double fontsi
         height = char_height(&dclextchar[prev_pos], prev_byte);
         sprintf(over_span,"<span letter_spacing='%d'> </span><span rise='%d' letter_spacing='%d'>",
                 -(cw0+sw), (int)(height*0.8), wdiff);
-        strcpy(&string[length], over_span); length += strlen(over_span); continue;
-      }
+        strcpy(&string[length], over_span); length += strlen(over_span); continue;*/
+
 
 
     }else{ /* 新しい書式 */
+      if (dclextchar[i] == sg_isup){ /* 上付き開始 */
+        strcpy(&string[length], sup_span); length += strlen(sup_span); continue;
+      }else if(dclextchar[i] == sg_isub){ /* 下付き開始 */
+        strcpy(&string[length], sub_span); length += strlen(sub_span); continue;
+      }else if(dclextchar[i] == sg_irst){ /* span終了 */
+        strcpy(&string[length], "</span>"); length += strlen("</span>"); continue;
+      }
       if (dclextchar[i] == 92){ /* 92 は バックスラッシュ（制御の始まり） */
         flag_inspan += 1;
         if (flag_close == i){ /* } がない場合の制御終了処理 */
@@ -1789,7 +1793,6 @@ void ZGQTXW(char* text, DCL_INT *len, DCL_REAL *wxch, DCL_REAL *wych)
   dcltext2pangomarkup(text, *len, string, 1.0*PANGO_SCALE*fact);
   pango_font_description_set_size(font_desc, 1.0*PANGO_SCALE*fact);
   get_pangostring_width_height(cr, string, &width, &height);
-
   *wxch = width*1.0/fact; //目で見て調整しただけ。
   *wych = height*0.8/fact;
 }
