@@ -33,7 +33,7 @@ static integer c__16 = 16;
     address a__1[3], a__2[2];
     integer i__1, i__2, i__3, i__4[3], i__5[2];
     real r__1, r__2;
-    char ch__1[7];
+    char ch__1[3], ch__2[3], ch__3[7];
     icilist ici__1;
 
     /* Builtin functions */
@@ -55,11 +55,11 @@ static integer c__16 = 16;
     static char chr[8], chw[16];
     static integer nbs, nbt;
     static real sgn, uyt[50], yyy;
-    extern /* Subroutine */ int gnge_(real *, real *, integer *);
+    extern /* Subroutine */ int gnge_(real *, real *, integer *), gnle_(real *
+	    , real *, integer *);
     static logical loff;
-    extern /* Subroutine */ int gnle_(real *, real *, integer *);
     static char cfmt[16];
-    extern real usgi_(integer *);
+    extern /* Character */ VOID usgi_(char *, ftnlen, integer *);
     extern logical lrgt_(real *, real *);
     extern integer lenz_(char *, ftnlen);
     static real ymin;
@@ -224,8 +224,9 @@ L100:
 			s_wsfi(&ici__1);
 			i__3 = (integer) bl[ib - 1];
 			do_fio(&c__1, (char *)&i__3, (ftnlen)sizeof(integer));
-			r__1 = usgi_(&iychr);
-			do_fio(&c__1, (char *)&r__1, (ftnlen)sizeof(real));
+			usgi_(ch__2, (ftnlen)3, &iychr);
+			s_copy(ch__1, ch__2, (ftnlen)3, (ftnlen)3);
+			do_fio(&c__1, ch__1, (ftnlen)3);
 			e_wsfi();
 		    } else {
 			s_copy(ch + (nbl - 1) * 18, " ", (ftnlen)18, (ftnlen)
@@ -235,25 +236,12 @@ L100:
 		    do_fio(&c__1, (char *)&ip, (ftnlen)sizeof(integer));
 		    e_wsfi();
 		    cladj_(chr, (ftnlen)8);
-		    if (lcntl) {
-/*              IF(LSFNT) THEN */
 /* Writing concatenation */
-			i__4[0] = 5, a__1[0] = "10\\^{";
-			i__4[1] = lenz_(chr, (ftnlen)8), a__1[1] = chr;
-			i__4[2] = 1, a__1[2] = "}";
-			s_cat(ch + ((nbl - 1) * 18 + 4), a__1, i__4, &c__3, (
-				ftnlen)14);
-/*              ELSE */
-/*                CH(NBL)(3:16)='10'//CSGI(ISUP)//CHR(1:LENZ(CHR)) */
-/*     +            //CSGI(IRST) */
-/*              END IF */
-		    } else {
-/* Writing concatenation */
-			i__5[0] = 1, a__2[0] = "E";
-			i__5[1] = 8, a__2[1] = chr;
-			s_cat(ch + ((nbl - 1) * 18 + 3), a__2, i__5, &c__2, (
-				ftnlen)15);
-		    }
+		    i__4[0] = 5, a__1[0] = "10\\^{";
+		    i__4[1] = lenz_(chr, (ftnlen)8), a__1[1] = chr;
+		    i__4[2] = 1, a__1[2] = "}";
+		    s_cat(ch + ((nbl - 1) * 18 + 4), a__1, i__4, &c__3, (
+			    ftnlen)14);
 		    cladj_(ch + (nbl - 1) * 18, (ftnlen)18);
 		}
 	    } else {
@@ -301,8 +289,8 @@ L201:
 /* Writing concatenation */
     i__5[0] = 6, a__2[0] = "LABELY";
     i__5[1] = 1, a__2[1] = cside;
-    s_cat(ch__1, a__2, i__5, &c__2, (ftnlen)7);
-    uzlget_(ch__1, &label, (ftnlen)7);
+    s_cat(ch__3, a__2, i__5, &c__2, (ftnlen)7);
+    uzlget_(ch__3, &label, (ftnlen)7);
     if (label) {
 	uyplbl_(cside, &c__1, uy2, ch, &c__16, &nbl, (ftnlen)1, (ftnlen)18);
     }
