@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -26,7 +26,7 @@ struct {
 /* ----------------------------------------------------------------------- */
 /*     UMSCOM : COMMON BLOCK SETTING */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int umscom_(void)
 {
@@ -51,8 +51,8 @@ struct {
     }
 /* ----------------------------- ITR (CHECK)------------------------------ */
     sgqtrn_(&umwk1_1.itr);
-    if (! (10 <= umwk1_1.itr && umwk1_1.itr <= 15 || 20 <= umwk1_1.itr && 
-	    umwk1_1.itr <= 23 || 30 <= umwk1_1.itr && umwk1_1.itr <= 33)) {
+    if (! (10 <= umwk1_1.itr && umwk1_1.itr <= 24 || 30 <= umwk1_1.itr && 
+	    umwk1_1.itr <= 34)) {
 	msgdmp_("E", "UMSCOM", "INVALID TRANSFORMATION NUMBER.", (ftnlen)1, (
 		ftnlen)6, (ftnlen)30);
     }
