@@ -1,4 +1,4 @@
-/*  -- translated by f2c (version 20050501).
+/*  -- translated by f2c (version 20100827).
    You must link the resulting object file with libf2c:
 	on Microsoft Windows system, link with libf2c.lib;
 	on Linux or Unix systems, link with .../path/to/libf2c.a -lm
@@ -20,12 +20,18 @@ static integer c__3 = 3;
 /* ----------------------------------------------------------------------- */
 /*     GET EXTERNAL PARAMETER FROM 'DCLRC' FILE */
 /* ----------------------------------------------------------------------- */
-/*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved. */
+/*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved. */
 /* ----------------------------------------------------------------------- */
 /* Subroutine */ int rpnxfl_0_(int n__, char *cpfix, char *cp, integer *ipara,
 	 logical *lpara, real *rpara, char *cval, ftnlen cpfix_len, ftnlen 
 	cp_len, ftnlen cval_len)
 {
+    /* Initialized data */
+
+    static char csepx[1] = "_";
+    static char ccomx[1] = "*";
+    static char cdivx[1] = " ";
+
     /* System generated locals */
     address a__1[3];
     integer i__1, i__2[3];
@@ -49,7 +55,7 @@ static integer c__3 = 3;
     static integer ios;
     static char cadj[32], ccom[1];
     extern integer lenc_(char *, ftnlen);
-    static char cdiv[1], cdsn[80], csep[1];
+    static char cdiv[1], cdsn[1024], csep[1];
     extern /* Subroutine */ int cladj_(char *, ftnlen);
     static char cpara[80*100], cline[80];
     extern logical lchreq_(char *, char *, ftnlen, ftnlen);
@@ -62,10 +68,9 @@ static integer c__3 = 3;
     extern /* Subroutine */ int osgenv_(char *, char *, ftnlen, ftnlen);
 
     /* Fortran I/O blocks */
-    static cilist io___8 = { 1, 0, 1, "(A)", 0 };
+    static cilist io___11 = { 1, 0, 1, "(A)", 0 };
 
 
-/*     DATA      CCOM / '*' /, CDIV / ' ' / */
     switch(n__) {
 	case 1: goto L_rtixfl;
 	case 2: goto L_rtlxfl;
@@ -79,16 +84,18 @@ static integer c__3 = 3;
 
     osgenv_("DCLENVCHAR", csep, (ftnlen)10, (ftnlen)1);
     if (*(unsigned char *)csep == ' ') {
-	*(unsigned char *)csep = ':';
+	*(unsigned char *)csep = *(unsigned char *)&csepx[0];
     }
     osgenv_("DCLCOMCHAR", ccom, (ftnlen)10, (ftnlen)1);
     if (*(unsigned char *)ccom == ' ') {
-	*(unsigned char *)ccom = '*';
+	*(unsigned char *)ccom = *(unsigned char *)&ccomx[0];
     }
     osgenv_("DCLDIVCHAR", cdiv, (ftnlen)10, (ftnlen)1);
-/*     IF (CDIV.EQ.' ') CDIV=' ' */
-    glqfnm_("DCLRC", cdsn, (ftnlen)5, (ftnlen)80);
-    if (s_cmp(cdsn, " ", (ftnlen)80, (ftnlen)1) == 0) {
+    if (*(unsigned char *)cdiv == ' ') {
+	*(unsigned char *)cdiv = *(unsigned char *)&cdivx[0];
+    }
+    glqfnm_("DCLRC", cdsn, (ftnlen)5, (ftnlen)1024);
+    if (s_cmp(cdsn, " ", (ftnlen)1024, (ftnlen)1) == 0) {
 	return 0;
     }
     iu = iufopn_();
@@ -97,7 +104,7 @@ static integer c__3 = 3;
     }
     o__1.oerr = 0;
     o__1.ounit = iu;
-    o__1.ofnmlen = 80;
+    o__1.ofnmlen = 1024;
     o__1.ofnm = cdsn;
     o__1.orl = 0;
     o__1.osta = 0;
@@ -110,8 +117,8 @@ static integer c__3 = 3;
     f_rew(&al__1);
     nn = 0;
 L10:
-    io___8.ciunit = iu;
-    ios = s_rsfe(&io___8);
+    io___11.ciunit = iu;
+    ios = s_rsfe(&io___11);
     if (ios != 0) {
 	goto L100001;
     }
